#ifndef LIBKYSEC_RBAC_H__
#define LIBKYSEC_RBAC_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
 * 添加三权用户信息
 * 参数： user：用户名 filepath：文件名（取绝对路径）
 * 返回值: 0 : 成功 -1 : 失败 -2: 系统默认命令不可修改
 */
int rbac_add(char* user, char *filepath);

/*
 * 删除三权用户信息
 * 参数： user：用户名 filepath：文件名（取绝对路径）
 * 返回值: 0 : 成功 -1 : 失败 -2: 系统默认命令不可修改
 */
int rbac_del(char* user, char *filepath);

/*
 * 设置三权分立状态
 * 参数：0：关闭 1：开启
 * 返回值: 0 : 成功 -1 : 失败
 */
int rbac_setstatus(int status);

/*
 * 查询是否是三元命令
 * 参数：filepath：文件名（取绝对路径）
 *       user: 输出参数，返回只允许命令执行的用户
 *       native：输出参数，1：系统默认配置，0：用户配置
 * 返回值: 0 : 成功 -1 : 失败
 */
int rbac_query(char *filepath, char** user, int *native);

/*
 * 获取所有的三元命令
 * 参数：buffer：输出所有的三元命令
 *       格式为：
 * 
 *       用户名1 default/user config
 * 
 *       命令1
 *       命令2
 *       ...
 *       命令n
 * 
 *       ...
 * 
 *       用户名n default/user config
 * 
 *       命令1
 *       命令2
 *       ...
 *       命令n
 * 
 * 返回值: 0 : 成功 -1 : 失败
 */
int rbac_query_all(char** buffer);

#ifdef __cplusplus
}
#endif

#endif
